"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* globals console, jest, expect, describe, it */
var componentTest = function componentTest(Component) {
  return describe('acts like a formsy-react-component', function () {
    it('warns when no `id` prop is provided', function () {
      /* eslint-disable no-console */
      var _console = console,
          error = _console.error;
      console.error = jest.fn();
      /* eslint-disable no-unused-vars */

      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(Component, {
        name: "myName"
      }));
      /* eslint-enable no-unused-vars */

      var errorMessages = console.error.mock.calls.map(function (args) {
        return args[0];
      }).join('\n');
      expect(console.error).toBeCalled();
      expect(errorMessages).toContain('Warning: Failed prop type: The prop `id` is marked as required in');
      console.error = error;
      /* eslint-enable no-console */
    });
    it('renders a row label (when label prop is provided)', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(Component, {
        name: "myTestInput",
        label: "My Label"
      }));
      expect(wrapper.find('.control-label').length).toBe(1);
      expect(wrapper.find('.control-label').text()).toEqual('My Label');
    });
    it('renders help text', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(Component, {
        name: "myTestInput",
        help: "My help text."
      }));
      expect(wrapper.find('.help-block').length).toEqual(1);
    });
    it('indicates required content with a symbol', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(Component, {
        name: "myTestInput",
        required: true
      }));
      expect(wrapper.find('.required-symbol').length).toEqual(1);
    });
    it('displays error messages', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(Component, {
        name: "myTestInput",
        showErrors: true,
        errorMessages: ['An error message.']
      }));
      expect(wrapper.find('.help-block.validation-message').length).toEqual(1);
      expect(wrapper.find('div.has-error.has-feedback').length).toEqual(1);
    });
  });
};

var _default = componentTest;
exports.default = _default;