"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var debounce = function debounce(fn, time) {
  var pending;
  var lastArgs;
  var lastThis;

  var cancel = function cancel() {
    clearTimeout(pending);
    pending = undefined;
  };

  var run = function run() {
    if (lastArgs) {
      var currentThis = lastThis;
      var currentArgs = lastArgs;
      lastThis = undefined;
      lastArgs = undefined;
      fn.apply(currentThis, currentArgs);
    }
  };

  var flush = function flush() {
    cancel();
    run();
  };

  function debounced() {
    lastThis = this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    lastArgs = args;

    if (pending) {
      clearTimeout(pending);
    }

    pending = setTimeout(run, time);
  }

  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
};

var _default = debounce;
exports.default = _default;